# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

import datetime
import os
import re
import sys

# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
sys.path.insert(0, os.path.abspath(".."))

# -- Project information -----------------------------------------------------

project = "nanoarrow"
copyright = f"2016-{datetime.datetime.now().year} Apache Software Foundation"
author = "Apache Software Foundation"


def get_version():
    cmakelists = os.path.join("..", "..", "CMakeLists.txt")
    with open(cmakelists, "r") as f:
        for line in f:
            if "NANOARROW_VERSION" in line:
                if "SNAPSHOT" in line:
                    return "dev"
                else:
                    return re.findall(r"[0-9]+\.[0-9]+\.[0-9]+", line)[0]


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "breathe",
    "sphinx.ext.autodoc",
]

cpp_id_attributes = ["NANOARROW_CHECK_PRINTF_ATTRIBUTE"]

# Breathe configuration
breathe_projects = {
    "nanoarrow_c": "../../src/apidoc/xml",
}
breathe_default_project = "nanoarrow_c"

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["README_generated.rst"]


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "pydata_sphinx_theme"

html_theme_options = {
    "show_toc_level": 2,
    "use_edit_page_button": True,
    "external_links": [],
    "switcher": {
        "json_url": "https://arrow.apache.org/nanoarrow/switcher.json",
        "version_match": get_version(),
    },
    "navbar_start": ["navbar-logo", "version-switcher"],
    "navigation_with_keys": False,
}

html_context = {
    "github_user": "apache",
    "github_repo": "arrow-nanoarrow",
    "github_version": "main",
    "doc_path": "docs/source",
}

html_sidebars = {"**": ["search-field", "sidebar-nav-bs"]}


# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []

add_module_names = False
